;; Generated package description from gpr-mode.el  -*- no-byte-compile: t -*-
(define-package "gpr-mode" "1.0.5.0.20231115.90848" "Major mode for editing GNAT project files" '((emacs "25.3") (wisi "4.3.2") (gnat-compiler "1.0.3")) :commit "9ca25ec5ca871f04b4704b39fb3ba129694e02ac" :authors '(("Stephen Leake" . "stephen_leake@member.fsf.org")) :maintainer '("Stephen Leake" . "stephen_leake@member.fsf.org") :url "https://stephe-leake.org/ada/wisitoken.html")
